@@ -1,27 +1,12 @@
 /*
- * ark -- archiver for the KDE project
- *
- * Copyright (C) 2002-2003: Georg Robbers <Georg.Robbers@urz.uni-hd.de>
- * Copyright (C) 2003: Helio Chissini de Castro <helio@conectiva.com>
- * Copyright (C) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
- * Copyright (C) 2008 Harald Hvaal <haraldhv@stud.ntnu.no>
- * Copyright (C) 2021 Jiří Wolker <woljiri@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- *
- */
+    SPDX-FileCopyrightText: 2002-2003 Georg Robbers <Georg.Robbers@urz.uni-hd.de>
+    SPDX-FileCopyrightText: 2003 Helio Chissini de Castro <helio@conectiva.com>
+    SPDX-FileCopyrightText: 2007 Henrique Pinto <henrique.pinto@kdemail.net>
+    SPDX-FileCopyrightText: 2008 Harald Hvaal <haraldhv@stud.ntnu.no>
+    SPDX-FileCopyrightText: 2021 Jiří Wolker <woljiri@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mainwindow.h"
 #include "ark_debug.h"
@@ -31,7 +16,6 @@
 #include "settingspage.h"
 #include "pluginmanager.h"
 #include "interface.h"
-#include "welcomescreen.h"
 
 #include <KParts/ReadWritePart>
 #include <KPluginFactory>
@@ -53,7 +37,6 @@
 #include <QMimeData>
 #include <QPointer>
 #include <QStatusBar>
-#include <QStackedWidget>
 
 static bool isValidArchiveDrag(const QMimeData *data)
 {
